@@ -423,76 +423,51 @@ class ColorHandler(logging.Handler):
         finally:
             self.release()
 
-    def __display_with_backgroud_color(self,record:logging.LogRecord):
-        try:
-            # very_nb_print(record)
-            effective_information_msg = record.msg
-            record.msg = ''
-            msg = self.format(record)
-            stream = self.stream
-            if record.levelno == 10:
-                # msg_color = ('\033[0;32m%s\033[0m' % msg)  # 绿色
-                # print(msg1)
-                msg_color = f'\033[0;32m{msg}\033[0m \033[0;{self._word_color};42m{effective_information_msg}\033[0m'  # 绿色
-            elif record.levelno == 20:
-                # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.bule, msg))  # 青蓝色 36    96
-                msg_color = f'\033[0;36m{msg}\033[0m \033[0;{self._word_color};46m{effective_information_msg}\033[0m'
-            elif record.levelno == 30:
-                # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.yellow, msg))
-                msg_color = f'\033[0;33m{msg}\033[0m \033[0;{self._word_color};43m{effective_information_msg}\033[0m'
-            elif record.levelno == 40:
-                # msg_color = ('\033[%s;35m%s\033[0m' % (self._display_method, msg))  # 紫红色
-                msg_color = f'\033[0;35m{msg}\033[0m \033[0;{self._word_color};45m{effective_information_msg}\033[0m'
-            elif record.levelno == 50:
-                # msg_color = ('\033[%s;31m%s\033[0m' % (self._display_method, msg))  # 血红色
-                msg_color = f'\033[0;31m{msg}\033[0m \033[0;{self._word_color};41m{effective_information_msg}\033[0m'
-            else:
-                msg_color = msg
-            # print(msg_color,'***************')
-            stream.write(msg_color)
-            stream.write(self.terminator)
-            self.flush()
-        except Exception as e:
-            very_nb_print(e)
-            very_nb_print(traceback.format_exc())
-            # self.handleError(record)
+    def __build_color_msg_with_backgroud_color(self, record_level, assist_msg, effective_information_msg):
 
-    def __display_with_no_backgroud_color(self, record:logging.LogRecord):
-        try:
-            # very_nb_print(record)
-            effective_information_msg = record.msg
-            record.msg=''
-            msg = self.format(record)
-            stream = self.stream
-            # msg1, msg2 = self.__spilt_msg(record.levelno, msg)
-            if record.levelno == 10:
-                # msg_color = ('\033[0;32m%s\033[0m' % msg)  # 绿色
-                # print(msg1)
-                msg_color = f'\033[0;32m{msg} {effective_information_msg}\033[0m'  # 绿色
-            elif record.levelno == 20:
-                # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.bule, msg))  # 青蓝色 36    96
-                msg_color = f'\033[0;36m{msg} {effective_information_msg}\033[0m'
-            elif record.levelno == 30:
-                # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.yellow, msg))
-                msg_color = f'\033[0;33m{msg} {effective_information_msg}\033[0m'
-            elif record.levelno == 40:
-                # msg_color = ('\033[%s;35m%s\033[0m' % (self._display_method, msg))  # 紫红色
-                msg_color = f'\033[0;35m{msg} {effective_information_msg}\033[0m'
-            elif record.levelno == 50:
-                # msg_color = ('\033[%s;31m%s\033[0m' % (self._display_method, msg))  # 血红色
-                msg_color = f'\033[0;31m{msg} {effective_information_msg}\033[0m'
-            else:
-                msg_color = msg
-            # print(msg_color,'***************')
-            stream.write(msg_color)
-            stream.write(self.terminator)
-            self.flush()
-        except Exception as e:
-            very_nb_print(e)
-            very_nb_print(traceback.format_exc())
-            # self.handleError(record)
+        if record_level == 10:
+            # msg_color = ('\033[0;32m%s\033[0m' % msg)  # 绿色
+            # print(msg1)
+            msg_color = f'\033[0;32m{assist_msg}\033[0m \033[0;{self._word_color};42m{effective_information_msg}\033[0m'  # 绿色
+        elif record_level == 20:
+            # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.bule, msg))  # 青蓝色 36    96
+            msg_color = f'\033[0;36m{assist_msg}\033[0m \033[0;{self._word_color};46m{effective_information_msg}\033[0m'
+        elif record_level == 30:
+            # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.yellow, msg))
+            msg_color = f'\033[0;33m{assist_msg}\033[0m \033[0;{self._word_color};43m{effective_information_msg}\033[0m'
+        elif record_level == 40:
+            # msg_color = ('\033[%s;35m%s\033[0m' % (self._display_method, msg))  # 紫红色
+            msg_color = f'\033[0;35m{assist_msg}\033[0m \033[0;{self._word_color};45m{effective_information_msg}\033[0m'
+        elif record_level == 50:
+            # msg_color = ('\033[%s;31m%s\033[0m' % (self._display_method, msg))  # 血红色
+            msg_color = f'\033[0;31m{assist_msg}\033[0m \033[0;{self._word_color};41m{effective_information_msg}\033[0m'
+        else:
+            msg_color = f'{assist_msg}  {effective_information_msg}'
+        return msg_color
 
-    def emit(self, record):
+    def __build_color_msg_with_no_backgroud_color(self, record_level, assist_msg, effective_information_msg):
+
+        if record_level == 10:
+            # msg_color = ('\033[0;32m%s\033[0m' % msg)  # 绿色
+            # print(msg1)
+            msg_color = f'\033[0;32m{assist_msg} {effective_information_msg}\033[0m'  # 绿色
+        elif record_level == 20:
+            # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.bule, msg))  # 青蓝色 36    96
+            msg_color = f'\033[0;36m{assist_msg} {effective_information_msg}\033[0m'
+        elif record_level == 30:
+            # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.yellow, msg))
+            msg_color = f'\033[0;33m{assist_msg} {effective_information_msg}\033[0m'
+        elif record_level == 40:
+            # msg_color = ('\033[%s;35m%s\033[0m' % (self._display_method, msg))  # 紫红色
+            msg_color = f'\033[0;35m{assist_msg} {effective_information_msg}\033[0m'
+        elif record_level == 50:
+            # msg_color = ('\033[%s;31m%s\033[0m' % (self._display_method, msg))  # 血红色
+            msg_color = f'\033[0;31m{assist_msg} {effective_information_msg}\033[0m'
+        else:
+            msg_color = f'{assist_msg}  {effective_information_msg}'
+        return msg_color
+
+    def emit(self, record: logging.LogRecord):
         """
         Emit a record.
 
@@ -504,11 +479,25 @@ class ColorHandler(logging.Handler):
         output to the stream.
         """
         # noinspection PyBroadException
-        if nb_log_config_default.DISPLAY_BACKGROUD_COLOR_IN_CONSOLE:
-            self.__display_with_backgroud_color(record)
-        else:
-            self.__display_with_no_backgroud_color(record)
-
+        try:
+            # very_nb_print(record)
+            effective_information_msg = record.msg
+            record.msg = ''
+            assist_msg = self.format(record)
+            stream = self.stream
+            if nb_log_config_default.DISPLAY_BACKGROUD_COLOR_IN_CONSOLE:
+                msg_color = self.__build_color_msg_with_backgroud_color(record.levelno, assist_msg,
+                                                                        effective_information_msg)
+            else:
+                msg_color = self.__build_color_msg_with_no_backgroud_color(record.levelno, assist_msg,
+                                                                           effective_information_msg)
+            stream.write(msg_color)
+            stream.write(self.terminator)
+            self.flush()
+        except Exception as e:
+            very_nb_print(e)
+            very_nb_print(traceback.format_exc())
+            # self.handleError(record)
 
     @staticmethod
     def __spilt_msg(log_level, msg: str):
