@@ -21,7 +21,7 @@ ALWAYS_ADD_KAFKA_HANDLER_IN_TEST_ENVIRONENT = False
 MONGO_URL = 'mongodb://myUserAdmin:mimamiama@127.0.0.1:27016/admin'
 
 DEFAULUT_USE_COLOR_HANDLER = True  # 是否默认使用有彩的日志。
-DISPLAY_BACKGROUD_COLOR_IN_CONSOLE = True     # 在控制台是否显示彩色块状的日志。为False则不使用大块的背景颜色。
+DISPLAY_BACKGROUD_COLOR_IN_CONSOLE = True  # 在控制台是否显示彩色块状的日志。为False则不使用大块的背景颜色。
 AUTO_PATCH_PRINT = True  # 是否自动打print的猴子补丁，如果打了后指不定，print自动变色和可点击跳转。
 WARNING_PYCHARM_COLOR_SETINGS = True
 
@@ -50,7 +50,7 @@ FORMATTER_DICT = {
         "%Y-%m-%d %H:%M:%S"),  # 我认为的最好的模板,推荐
     6: logging.Formatter('%(name)s - %(asctime)-15s - %(filename)s - %(lineno)d - %(levelname)s: %(message)s',
                          "%Y-%m-%d %H:%M:%S"),
-    7: logging.Formatter('%(levelname)s - %(filename)s - %(lineno)d - %(message)s'),  # 一个只显示简短文件名和所处行数的日志模板
+    7: logging.Formatter('%(levelname)s - %(filename)s - %(lineno)d - %(message)s',"%Y-%m-%d %H:%M:%S"), # 一个只显示简短文件名和所处行数的日志模板
 }
 
-FORMATTER_KIND = 5  # 选择第几个模板
+FORMATTER_KIND = 5  # 如果get_logger_and_add_handlers不指定日志模板，则默认选择第几个模板
