@@ -41,7 +41,7 @@ def nb_print(*args, sep=' ', end='\n', file=None):
 def show_nb_log_config():
     nb_print('显示nb_log 包的默认的低优先级的配置参数')
     for var_name in dir(nb_log_config_default):
-        nb_print(var_name, getattr(nb_log_config_default,':', var_name))
+        nb_print(var_name, getattr(nb_log_config_default, ':', var_name))
     print('\n')
 
 
@@ -49,7 +49,13 @@ config_file_content = '''# -*- coding: utf-8 -*-
 """
 此文件nb_log_config.py是自动生成到python项目的根目录的。
 在这里面写的变量会覆盖此文件nb_log_config_default中的值。对nb_log包进行默认的配置。
-但最终配置方式是由get_logger_and_add_handlers方法的各种传参决定，如果方法相应的传参为None则使用这里面的配置。
+
+由于不同的logger天然就是多个实例，所以可以通过get_logger_and_handlers传参针对每个logger精确的做不同的配置。
+最终配置方式是由get_logger_and_add_handlers方法的各种传参决定，如果方法相应的传参为None则使用这里面的配置。
+最终配置方式是由get_logger_and_add_handlers方法的各种传参决定，如果方法相应的传参为None则使用这里面的配置。
+最终配置方式是由get_logger_and_add_handlers方法的各种传参决定，如果方法相应的传参为None则使用这里面的配置。
+重要的重复三遍。
+
 """
 import logging
 # 
@@ -68,7 +74,7 @@ import logging
 # 
 # MONGO_URL = 'mongodb://myUserAdmin:mimamiama@127.0.0.1:27016/admin'
 # 
-# DEFAULUT_USE_COLOR_HANDLER = True  # 是否默认使用有彩的日志。
+# DEFAULUT_USE_COLOR_HANDLER = True  # 是否默认使用有彩的日志。有的人讨厌彩色可以关掉（主要是不按提示的说明配置pycahrm的conose）。
 # DISPLAY_BACKGROUD_COLOR_IN_CONSOLE = True     # 在控制台是否显示彩色块状的日志。为False则不使用大块的背景颜色。
 # AUTO_PATCH_PRINT = True  # 是否自动打print的猴子补丁，如果打了后指不定，print自动变色和可点击跳转。
 # WARNING_PYCHARM_COLOR_SETINGS = True
@@ -101,7 +107,7 @@ import logging
 #     7: logging.Formatter('%(levelname)s - %(filename)s - %(lineno)d - %(message)s'),  # 一个只显示简短文件名和所处行数的日志模板
 # }
 # 
-# FORMATTER_KIND = 5  # 如果get选择第几个模板
+# FORMATTER_KIND = 5  # 默认选择第几个模板
 
 '''
 
@@ -122,13 +128,11 @@ def use_config_form_distributed_frame_config_module():
             if var_namex.isupper():
                 setattr(nb_log_config_default, var_namex, var_valuex)
     except ModuleNotFoundError:
-        msg = '在你的项目根目录下生成了 nb_log_config.py 的nb_log包的日志配置文件，快去看看并修改一些自定义配置吧'
+        msg = f'''在你的项目根目录下生成了 \n "{Path(sys.path[1]) / Path('nb_log_config.py')}:1" 的nb_log包的日志配置文件，快去看看并修改一些自定义配置吧'''
         sys.stdout.write(f'{time.strftime("%H:%M:%S")}  "{file_name}:{line}"   {msg} \n \033[0m')
         auto_creat_config_file_to_project_root_path()
 
 
-
-
 def auto_creat_config_file_to_project_root_path():
     # print(Path(sys.path[1]).as_posix())
     # print((Path(__file__).parent.parent).absolute().as_posix())
